@@ -6,9 +6,9 @@ pub(super) mod bitget;
 pub(super) mod bitmex;
 pub(super) mod bybit;
 pub(super) mod deribit;
-pub(super) mod ftx;
 pub(super) mod gate;
 pub(super) mod huobi;
 pub(super) mod kucoin;
 pub(super) mod mxc;
 pub(super) mod okex;
+pub(super) mod zbg;
