@@ -14,22 +14,30 @@ lazy_static! {
             ("ACH/USDT", 1_f64),
             ("ADA/USDT", 1_f64),
             ("AGLD/USDT", 0.1_f64),
+            ("AKITA/USDT", 1000000_f64),
             ("AKRO/USDT", 1_f64),
+            ("ALGO/USDT", 1_f64),
             ("ALICE/USDT", 0.1_f64),
             ("ALPHA/USDT", 1_f64),
             ("ANKR/USDT", 1_f64),
+            ("ANT/USDT", 1_f64),
+            ("AR/USDT", 0.1_f64),
             ("ARPA/USDT", 1_f64),
             ("ATA/USDT", 1_f64),
             ("ATOM/USDT", 0.1_f64),
             ("AUDIO/USDT", 1_f64),
             ("AVAX/USDT", 0.1_f64),
             ("AXS/USDT", 1_f64),
+            ("BABY/USDT", 10_f64),
+            ("BABYDOGE/USDT", 1000000000_f64),
+            ("BADGER/USDT", 0.1_f64),
             ("BAL/USDT", 0.1_f64),
             ("BAND/USDT", 0.1_f64),
             ("BAT/USDT", 1_f64),
             ("BCH/USDT", 0.01_f64),
             ("BIT/USDT", 1_f64),
             ("BNB/USDT", 0.01_f64),
+            ("BOBA/USDT", 1_f64),
             ("BP/USDT", 0.1_f64),
             ("BSV/USDT", 0.01_f64),
             ("BTC/USDT", 0.0001_f64),
@@ -38,12 +46,16 @@ lazy_static! {
             ("BTT/USDT", 1_f64),
             ("BZZ/USDT", 0.1_f64),
             ("C98/USDT", 1_f64),
+            ("CEEK/USDT", 10_f64),
             ("CELO/USDT", 1_f64),
             ("CELR/USDT", 1_f64),
             ("CFX/USDT", 1_f64),
+            ("CHR/USDT", 10_f64),
             ("CHZ/USDT", 1_f64),
+            ("COCOS/USDT", 1_f64),
             ("COMP/USDT", 0.01_f64),
             ("COTI/USDT", 1_f64),
+            ("CRO/USDT", 10_f64),
             ("CRV/USDT", 0.1_f64),
             ("CSPR/USDT", 1_f64),
             ("CTK/USDT", 1_f64),
@@ -57,7 +69,9 @@ lazy_static! {
             ("DYDX/USDT", 1_f64),
             ("EDEN/USDT", 1_f64),
             ("EGLD/USDT", 0.1_f64),
+            ("ELON/USDT", 1000000_f64),
             ("ENJ/USDT", 1_f64),
+            ("ENS/USDT", 0.1_f64),
             ("EOS/USDT", 0.1_f64),
             ("ETC/USDT", 0.1_f64),
             ("ETH/USDT", 0.01_f64),
@@ -68,6 +82,7 @@ lazy_static! {
             ("FTM/USDT", 1_f64),
             ("FTT/USDT", 0.1_f64),
             ("GALA/USDT", 10_f64),
+            ("GODS/USDT", 1_f64),
             ("GRT/USDT", 1_f64),
             ("GTC/USDT", 0.1_f64),
             ("HBAR/USDT", 1_f64),
@@ -76,23 +91,28 @@ lazy_static! {
             ("HT/USDT", 0.1_f64),
             ("ICP/USDT", 0.01_f64),
             ("ICX/USDT", 1_f64),
+            ("IMX/USDT", 1_f64),
             ("IOST/USDT", 100_f64),
             ("IOTA/USDT", 1_f64),
             ("IOTX/USDT", 1_f64),
             ("KAVA/USDT", 0.1_f64),
             ("KEEP/USDT", 1_f64),
+            ("KISHU/USDT", 1000000000_f64),
             ("KLAY/USDT", 1_f64),
             ("KNC/USDT", 0.1_f64),
             ("KSM/USDT", 0.01_f64),
             ("LINA/USDT", 1_f64),
             ("LINK/USDT", 0.1_f64),
             ("LIT/USDT", 0.1_f64),
+            ("LPT/USDT", 0.1_f64),
             ("LRC/USDT", 1_f64),
             ("LTC/USDT", 0.01_f64),
             ("LUNA/USDT", 1_f64),
             ("MANA/USDT", 1_f64),
             ("MASK/USDT", 0.1_f64),
             ("MATIC/USDT", 1_f64),
+            ("MBOX/USDT", 1_f64),
+            ("MELI/USDT", 10_f64),
             ("MINA/USDT", 1_f64),
             ("MKR/USDT", 0.01_f64),
             ("MTL/USDT", 1_f64),
@@ -107,6 +127,8 @@ lazy_static! {
             ("OMG/USDT", 0.1_f64),
             ("ONE/USDT", 1_f64),
             ("ONT/USDT", 1_f64),
+            ("PIT/USDT", 1000000000_f64),
+            ("PSP/USDT", 1_f64),
             ("QTUM/USDT", 0.1_f64),
             ("RACA/USDT", 1000_f64),
             ("RAY/USDT", 0.1_f64),
@@ -121,18 +143,23 @@ lazy_static! {
             ("SNX/USDT", 0.1_f64),
             ("SOL/USDT", 0.1_f64),
             ("SRM/USDT", 0.1_f64),
+            ("STARL/USDT", 100000_f64),
             ("STMX/USDT", 1_f64),
             ("STORJ/USDT", 1_f64),
             ("SUSHI/USDT", 0.1_f64),
             ("SXP/USDT", 1_f64),
             ("THETA/USDT", 1_f64),
             ("TLM/USDT", 1_f64),
+            ("TONCOIN/USDT", 1_f64),
             ("TORN/USDT", 0.01_f64),
             ("TRX/USDT", 10_f64),
+            ("UMA/USDT", 0.1_f64),
             ("UNI/USDT", 0.1_f64),
             ("VET/USDT", 1_f64),
             ("WAVES/USDT", 0.1_f64),
+            ("WAXP/USDT", 10_f64),
             ("XCH/USDT", 0.01_f64),
+            ("XEC/USDT", 10000_f64),
             ("XEM/USDT", 1_f64),
             ("XLM/USDT", 10_f64),
             ("XMR/USDT", 0.01_f64),
@@ -140,6 +167,7 @@ lazy_static! {
             ("XTZ/USDT", 0.1_f64),
             ("YFI/USDT", 0.0001_f64),
             ("YFII/USDT", 0.0001_f64),
+            ("YGG/USDT", 1_f64),
             ("ZEC/USDT", 0.01_f64),
             ("ZEN/USDT", 0.1_f64),
             ("ZIL/USDT", 10_f64),
